@@ -3,6 +3,7 @@ import functools
 import logging
 from typing import List, Optional, Tuple, Dict
 
+import yaml
 from pydantic import BaseModel, BaseSettings
 import jupyterhub.services.auth
 from fastapi import Depends, FastAPI, HTTPException, Request, status, APIRouter
@@ -35,8 +36,11 @@ class Settings(BaseSettings):
     # lazy prefix handling. Will want to put nginx in front of this.
     kbatch_prefix: str = ""
 
-    kbatch_job_node_affinity_required_label_key: Optional[str] = None
-    kbatch_job_node_affinity_required_label_value: Optional[str] = None
+    # A path to a YAML file defining a job template
+    kbatch_job_template_file: Optional[str] = None
+
+    # A path to a YAML file defining the profiles
+    kbatch_profile_file: Optional[str] = None
 
     # Jobs are cleaned up by Kubernetes after this many seconds.
     kbatch_job_ttl_seconds_after_finished: Optional[int] = 3600
@@ -51,37 +55,6 @@ class Settings(BaseSettings):
         env_file_encoding = "utf-8"
 
 
-settings = Settings()
-if settings.kbatch_init_logging:
-    import rich.logging
-
-    handler = rich.logging.RichHandler()
-    logger.setLevel(logging.INFO)
-    handler.setLevel(logging.INFO)
-    handler.setFormatter(
-        logging.Formatter("%(asctime)s:%(levelname)s:%(name)s:%(lineno)s:%(message)s")
-    )
-    logger.addHandler(handler)
-
-if (
-    settings.kbatch_job_node_affinity_required_label_key
-    and settings.kbatch_job_node_affinity_required_label_value
-):
-    pass
-elif (
-    settings.kbatch_job_node_affinity_required_label_key
-    or settings.kbatch_job_node_affinity_required_label_value
-):
-    raise ValueError(
-        "Must specify either both or neither of kbatch_job_node_affinity_required_label_key "
-        "and kbatch_job_node_affinity_required_label_value"
-    )
-
-
-app = FastAPI()
-router = APIRouter(prefix=settings.kbatch_prefix)
-
-
 class User(BaseModel):
     name: str
     groups: List[str]
@@ -98,6 +71,46 @@ class UserOut(BaseModel):
     groups: List[str]
 
 
+settings = Settings()
+if settings.kbatch_init_logging:
+    import rich.logging
+
+    handler = rich.logging.RichHandler()
+    logger.setLevel(logging.INFO)
+    handler.setLevel(logging.INFO)
+    handler.setFormatter(
+        logging.Formatter("%(asctime)s:%(levelname)s:%(name)s:%(lineno)s:%(message)s")
+    )
+    logger.addHandler(handler)
+
+if settings.kbatch_job_template_file:
+    logger.info("loading job template from %s", settings.kbatch_job_template_file)
+    with open(settings.kbatch_job_template_file) as f:
+        job_template = yaml.safe_load(f)
+
+    # parse with Kubernetes to normalize keys with job_data
+    job_template = utils.parse(
+        job_template, model=kubernetes.client.models.V1Job
+    ).to_dict()
+    utils.remove_nulls(job_template)
+
+else:
+    job_template = None
+
+
+if settings.kbatch_profile_file:
+    # TODO: we need some kind of validation on the keys / values here. Catch typos...
+    logger.info("loading profiles from %s", settings.kbatch_profile_file)
+    with open(settings.kbatch_profile_file) as f:
+        profile_data = yaml.safe_load(f)
+else:
+    profile_data = {}
+
+
+app = FastAPI()
+router = APIRouter(prefix=settings.kbatch_prefix)
+
+
 # ----------------------------------------------------------------------------
 # Jupyterhub configuration
 # TODO: make auth pluggable
@@ -164,6 +177,10 @@ async def create_job(request: Request, user: User = Depends(get_current_user)):
 
     data = await request.json()
     job_data = data["job"]
+
+    if job_template:
+        job_data = utils.merge_json_objects(job_data, job_template)
+
     job: kubernetes.client.models.V1Job = utils.parse(
         job_data, model=kubernetes.client.models.V1Job
     )
@@ -180,9 +197,6 @@ async def create_job(request: Request, user: User = Depends(get_current_user)):
     else:
         config_map = None
 
-    node_key = settings.kbatch_job_node_affinity_required_label_key
-    node_value = settings.kbatch_job_node_affinity_required_label_value
-
     patch.patch(
         job,
         config_map,
@@ -192,8 +206,6 @@ async def create_job(request: Request, user: User = Depends(get_current_user)):
         ttl_seconds_after_finished=settings.kbatch_job_ttl_seconds_after_finished,
         extra_env=settings.kbatch_job_extra_env,
         api_token=user.api_token,
-        job_node_affinity_required_label_key=node_key,
-        job_node_affinity_required_label_value=node_value,
     )
 
     # What needs to happen when? We have a few requirements
@@ -253,6 +265,11 @@ async def logs(job_name: str, user: User = Depends(get_current_user)):
     #     print(event)
 
 
+@router.get("/profiles/")
+async def profiles():
+    return profile_data
+
+
 @router.get("/")
 def get_root():
     logger.info("get-router")
